# Generated by Django 3.1.6 on 2021-04-22 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ehf_invoice', '0002_related_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoice',
            name='credit',
            field=models.BooleanField(default=False, verbose_name='kreditnota'),
        ),
    ]
